/* Copyright 2016 The TensorFlow Authors. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
==============================================================================*/
namespace vz_projector {

export class BrdfRenderAdapter {
  public renderer: BrdfRenderer;
  private labelToIndex: Map<string, number>;
  private indices: number[];
  private t: number;

  constructor(
      private container: HTMLElement) {
    this.renderer = new BrdfRenderer(container);
    this.labelToIndex = new Map<string, number>();
    LABELS.forEach((label, index) => {
      this.labelToIndex[label] = index;
    });
    this.indices = new Array<number>(2);
    this.indices[0] = this.indices[1] = -1;
  }

  updateMaterial(whichIndex: number, label: string) {
    const index = this.labelToIndex[label];
    this.indices[whichIndex] = index;
    this.renderer.updateMaterial(this.indices[0], this.indices[1], this.t);
  }

  updateParameter(t: number){
    this.t = t;
    this.renderer.updateMaterial(this.indices[0], this.indices[1], this.t);
  }
}

const LABELS = [
  'acrylic_felt_green_rgb',
  'acrylic_felt_orange_rgb',
  'acrylic_felt_pink_rgb',
  'acrylic_felt_purple_rgb',
  'acrylic_felt_white_rgb',
  'acrylic_felt_yellow_rgb',
  'alum-bronze',
  'alumina-oxide',
  'aluminium',
  'aurora_white_rgb',
  'aventurnine',
  'beige-fabric',
  'black-fabric',
  'black-obsidian',
  'black-oxidized-steel',
  'black-phenolic',
  'black-soft-plastic',
  'blue-acrylic',
  'blue-fabric',
  'blue-metallic-paint2',
  'blue-metallic-paint',
  'blue-rubber',
  'brass',
  'cardboard_rgb',
  'cc_amber_citrine_rgb',
  'cc_blue_agat_rgb',
  'cc_green_malachite_rgb',
  'cc_ibiza_sunset_rgb',
  'cc_iris_purple_gem_rgb',
  'cc_nothern_aurora_rgb',
  'cg_sunflower_rgb',
  'cherry-235',
  'chm_light_blue_rgb',
  'chm_mint_rgb',
  'chm_orange_rgb',
  'chrome-steel',
  'chrome',
  'cm_military_green_rgb',
  'cm_toxic_green_rgb',
  'cm_white_rgb',
  'colodur_azure_4e_rgb',
  'colodur_connemara_4c_rgb',
  'colodur_kalahari_2a_rgb',
  'colodur_napoli_4f_rgb',
  'colonial-maple-223',
  'color-changing-paint1',
  'color-changing-paint2',
  'color-changing-paint3',
  'dark-blue-paint',
  'dark-red-paint',
  'dark-specular-fabric',
  'delrin',
  'fruitwood-241',
  'gold-metallic-paint2',
  'gold-metallic-paint3',
  'gold-metallic-paint',
  'gold-paint',
  'gray-plastic',
  'grease-covered-steel',
  'green-acrylic',
  'green-fabric',
  'green-latex',
  'green-metallic-paint2',
  'green-metallic-paint',
  'green-plastic',
  'hematite',
  'ilm_l3_37_dark_green_rgb',
  'ilm_l3_37_matte_rgb',
  'ilm_l3_37_metallic_rgb',
  'ilm_solo_millennium_falcon_rgb',
  'ilm_solo_m_68_rgb',
  'ipswich-pine-221',
  'irid_flake_paint1_fine_rgb',
  'irid_flake_paint1_rgb',
  'irid_flake_paint2_rgb',
  'laika_ceiling_paint_18_gray_rgb',
  'leaf_maple_rgb',
  'light-brown-fabric',
  'light-red-paint',
  'maroon-plastic',
  'natural-209',
  'neoprene-rubber',
  'nickel',
  'nylon',
  'orange-paint',
  'paper_blue_rgb',
  'paper_green_rgb',
  'paper_red_rgb',
  'paper_white_rgb',
  'paper_yellow_rgb',
  'pearl-paint',
  'pickled-oak-260',
  'pink-fabric2',
  'pink-fabric',
  'pink-felt',
  'pink-jasper',
  'pink-plastic',
  'polyethylene',
  'polyurethane-foam',
  'pure-rubber',
  'purple-paint',
  'pvc',
  'red-fabric2',
  'red-fabric',
  'red-metallic-paint',
  'red-phenolic',
  'red-plastic',
  'red-specular-plastic',
  'satin_blue_rgb',
  'satin_gold_rgb',
  'satin_purple_rgb',
  'satin_rosaline_rgb',
  'satin_white_rgb',
  'silicon-nitrade',
  'silver-metallic-paint2',
  'silver-metallic-paint',
  'silver-paint',
  'special-walnut-224',
  'spectralon_rgb',
  'specular-black-phenolic',
  'specular-blue-phenolic',
  'specular-green-phenolic',
  'specular-maroon-phenolic',
  'specular-orange-phenolic',
  'specular-red-phenolic',
  'specular-violet-phenolic',
  'specular-white-phenolic',
  'specular-yellow-phenolic',
  'ss440',
  'steel',
  'teflon',
  'tungsten-carbide',
  'two-layer-gold',
  'two-layer-silver',
  'vch_dragon_eye_red_rgb',
  'vch_frozen_amethyst_rgb',
  'vch_golden_yellow_rgb',
  'vch_silk_blue_rgb',
  'vch_ultra_pink_rgb',
  'violet-acrylic',
  'violet-rubber',
  'white-acrylic',
  'white-diffuse-bball',
  'white-fabric2',
  'white-fabric',
  'white-marble',
  'white-paint',
  'yellow-matte-plastic',
  'yellow-paint',
  'yellow-phenolic',
  'yellow-plastic',
  ]
  // namespace vz_projector
}